==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QRunnable_shell.cpp <==
#include "QRunnable_shell.h"
#include <QtJambi/Cast>

void deleter_QRunnable(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRunnable")
    QRunnable *_ptr = reinterpret_cast<QRunnable *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QRunnable_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QRunnable_shell) ); }

jmethodID QRunnable_shell::__shell_javaMethod(int pos) const { return QRunnable_shell::__shell()->javaMethod(typeid(QRunnable), pos); }

// emitting (writeShellConstructor)
QRunnable_shell::QRunnable_shell()
    : QRunnable()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QRunnable::QRunnable_shell()", QRunnable_shell::__shell())
    QRunnable_shell::__shell()->constructed(typeid(QRunnable));
}

// emitting (writeShellDestructor)
QRunnable_shell::~QRunnable_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QRunnable::~QRunnable()", QRunnable_shell::__shell())
    QRunnable_shell::__shell()->destructed(typeid(QRunnable));
}

void QRunnable_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QRunnable_shell*>(ptr)->QRunnable_shell::__shell()->tryDeleteShell(typeid(QRunnable));
}

// emitting Virtual overrides (virtualFunctions)
void QRunnable_shell::run()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QRunnable::", QRunnable_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionBlocker __qj_exceptionBlocker;
            QtJambiExceptionInhibitor __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QRunnable_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QRunnable_shell::__shell()->warnForMethod("QRunnable::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QRunnable::");
            } QTJAMBI_TRY_END
            __qj_exceptionBlocker.release(__jni_env);
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QRunnable_access::__qt_run(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QtJambiExceptionBlocker __qj_exceptionBlocker;
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QRunnable::run()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QRunnable::run().";
    } else {
        run();
    }
    __qj_exceptionBlocker.release(__jni_env);
}

// emitting (writeConstructors)
// new QRunnable()
void __qt_construct_QRunnable(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRunnable()")
    Q_UNUSED(__java_arguments)
    QRunnable *__qt_this = new(__qtjambi_ptr) QRunnable_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QRunnable::QRunnable()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_initialize_1native__Lio_qt_core_QRunnable_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRunnable::QRunnable()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRunnable, sizeof(QRunnable_shell), typeid(QRunnable), true, &deleter_QRunnable, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QRunnable_shell
void __qt_destruct_QRunnable(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRunnable")
    reinterpret_cast<QRunnable_shell*>(ptr)->~QRunnable_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRunnable::autoDelete()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_autoDelete_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRunnable *__qt_this = QtJambiAPI::interfaceFromNativeId<QRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRunnable::autoDelete()const", __qt_this)
        __java_return_value = __qt_this->QRunnable::autoDelete();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRunnable::setAutoDelete(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_setAutoDelete_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jboolean _autoDelete0)
{
    QTJAMBI_TRY {
        QRunnable *__qt_this = QtJambiAPI::interfaceFromNativeId<QRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRunnable::setAutoDelete(bool)", __qt_this)
        __qt_this->QRunnable::setAutoDelete(static_cast<bool>(_autoDelete0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRunnable::run()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_00024ConcreteWrapper_run_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        QRunnable *__qt_this = QtJambiAPI::interfaceFromNativeId<QRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRunnable::run()", __qt_this)
        static_cast<QRunnable_access*>(__qt_this)->__qt_run(__jni_env, __this_nativeId);
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRunnable(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QRunnable>("QRunnable", "io/qt/core/QRunnable");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "()V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QRunnable, {
        ConstructorInfo(&__qt_construct_QRunnable, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRunnable);
    registerSizeOfShell(typeId, sizeof(QRunnable_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QRunnable* _object = dynamic_cast<QRunnable*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QRunnable *object = reinterpret_cast<QRunnable *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QRunnable *object = reinterpret_cast<const QRunnable *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QRunnable_shell.cpp <==
#include "QRunnable_shell.h"
#include <QtJambi/Cast>

void deleter_QRunnable(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRunnable")
    QRunnable *_ptr = reinterpret_cast<QRunnable *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QRunnable_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QRunnable_shell) ); }

jmethodID QRunnable_oshell::__shell_javaMethod(int pos) const { return QRunnable_shell::__shell()->javaMethod(typeid(QRunnable), pos); }

// emitting (writeShellDestructor)
QRunnable_shell::~QRunnable_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QRunnable::~QRunnable()", this)
    QRunnable_shell::__shell()->destructed(typeid(QRunnable));
}

// emitting (writeShellConstructor)
QRunnable_shell::QRunnable_shell()
    : QRunnable()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QRunnable::QRunnable_shell()", this)
    QRunnable_shell::__shell()->constructed(typeid(QRunnable));
}

void QRunnable_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QRunnable_oshell*>(ptr)->QRunnable_oshell::__shell()->tryDeleteShell(typeid(QRunnable));
}

// emitting Virtual overrides (virtualFunctions)
void QRunnable_oshell::run()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionInhibitorAndBlocker __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QRunnable_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QRunnable_shell::__shell()->warnForMethod("QRunnable::run()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QRunnable::run()");
            } QTJAMBI_TRY_END
            __jni_env.releaseException();
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QRunnable_access::__qt_run(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QtJambiExceptionBlocker __qj_exceptionBlocker;
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QRunnable::run()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QRunnable::run().";
    } else {
        run();
    }
    __qj_exceptionBlocker.release(__jni_env);
}

// emitting (writeConstructors)
// new QRunnable()
void __qt_construct_QRunnable(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRunnable()")
    Q_UNUSED(__java_arguments)
    QRunnable *__qt_this = new(__qtjambi_ptr) QRunnable_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QRunnable::QRunnable()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_initialize_1native__Lio_qt_core_QRunnable_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRunnable::QRunnable()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRunnable, sizeof(QRunnable_shell), typeid(QRunnable), 0, true, &deleter_QRunnable, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QRunnable_shell
void __qt_destruct_QRunnable(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRunnable")
    reinterpret_cast<QRunnable_shell*>(ptr)->~QRunnable_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRunnable::autoDelete()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_autoDelete_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRunnable *__qt_this = QtJambiAPI::interfaceFromNativeId<QRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRunnable::autoDelete()const", __this_nativeId)
        __java_return_value = __qt_this->QRunnable::autoDelete();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRunnable::setAutoDelete(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_setAutoDelete_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jboolean autoDelete0)
{
    QTJAMBI_TRY {
        QRunnable *__qt_this = QtJambiAPI::interfaceFromNativeId<QRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRunnable::setAutoDelete(bool)", __this_nativeId)
        __qt_this->QRunnable::setAutoDelete(static_cast<bool>(autoDelete0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRunnable::run()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRunnable_00024Impl_00024ConcreteWrapper_run_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        QRunnable *__qt_this = QtJambiAPI::interfaceFromNativeId<QRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRunnable::run()", __this_nativeId)
        static_cast<QRunnable_access*>(__qt_this)->__qt_run(__jni_env, __this_nativeId);
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRunnable(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QRunnable>("QRunnable", "io/qt/core/QRunnable");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "()V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QRunnable, {
        ConstructorInfo(&__qt_construct_QRunnable, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRunnable);
    registerSizeOfShell(typeId, sizeof(QRunnable_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QRunnable* _object = dynamic_cast<QRunnable*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QRunnable *object = reinterpret_cast<QRunnable *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QRunnable *object = reinterpret_cast<const QRunnable *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
